.whatsapp-widget{
    position: fixed;
    z-index: 100;
    bottom: 10px;
    right: 10px;
    display: flex;
    justify-content: center;
    align-items: center;
}
.whatsapp-widget-btn{
    height: 50px;
    width: 50px;
    background-color: green;
    border-radius: 50%;
    display: flex;
    justify-content: center;
    align-items: center;
}
.wa-icon{
    font-size: 27px;
}
.whatsapp-light{
    font-size: 25px;
    color: rgb(255, 255, 255) !important;
    text-decoration: none !important;
}
.text-to-chat{
    cursor: pointer;
    background-color: rgb(228, 228, 228);
    margin-right: 10px;
    border-radius: 2px;
    width: fit-content;
    height: min-content !important;
    padding:0px 4px 0px 4px;
}

.whatsapp-body{
    position: fixed;
    bottom: 80px;
    border-radius: 5px;
    right: 10px;
    height: auto;
    width: 280px;
    background-color: rgb(202, 202, 202);
    transition: height 0.35s ease !important;
    display: flex;
    flex-direction: column;
}
.whatsapp-body-header{
    background-color: green;
    border-radius: 5px 5px 0px 0px;
    width: 280px;
    
}
.whatsapp-header-text{
    text-align: center;
    font-size: 15px;
    color: #fff;
}
.whatsapp-accounts{
    display: flex;
    flex-direction: column;
    align-items: center !important;
}
.account-item{
    width: 260px;
    height: auto;
    border-radius: 8px;
    background-color: #fff;
    margin: 3px;
    border: 2px solid forestgreen;
    display: flex;
    justify-content: flex-end;
    align-items: center;
    padding: 3px;
}
.wa-avatar{
    width: 50px;
    height: 50px;
    border: 3px solid rgb(68, 216, 9);
    margin: 3px;
    border-radius: 50px;
}
.wa-acc-name{
    text-align: center;
}

.collapse:not(.show) {
    display: none;
  }
  
.collapsing {
    height: 0;
    overflow: hidden;
    transition: height 0.35s ease !important;
  }
@media (prefers-reduced-motion: reduce) {
    .collapsing {
      transition: none;
    }
  }
.collapsing.collapse-horizontal {
    width: 0;
    height: auto;
    transition: width 0.35s ease;
  }
@media (prefers-reduced-motion: reduce) {
    .collapsing.collapse-horizontal {
      transition: none;
    }
  }


.card {
    --bs-card-spacer-y: 1rem;
    --bs-card-spacer-x: 1rem;
    --bs-card-title-spacer-y: 0.5rem;
    --bs-card-border-width: 1px;
    --bs-card-border-color: var(--bs-border-color-translucent);
    --bs-card-border-radius: 0.375rem;
    --bs-card-box-shadow: ;
    --bs-card-inner-border-radius: calc(0.375rem - 1px);
    --bs-card-cap-padding-y: 0.5rem;
    --bs-card-cap-padding-x: 1rem;
    --bs-card-cap-bg: rgba(0, 0, 0, 0.03);
    --bs-card-cap-color: ;
    --bs-card-height: ;
    --bs-card-color: ;
    --bs-card-bg: #fff;
    --bs-card-img-overlay-padding: 1rem;
    --bs-card-group-margin: 0.75rem;
    position: relative;
    display: flex;
    flex-direction: column;
    min-width: 0;
    height: var(--bs-card-height);
    word-wrap: break-word;
    background-color: var(--bs-card-bg);
    background-clip: border-box;
    border: var(--bs-card-border-width) solid var(--bs-card-border-color);
    border-radius: var(--bs-card-border-radius);
  }

.card-body {
    flex: 1 1 auto;
    padding: var(--bs-card-spacer-y) var(--bs-card-spacer-x);
    color: var(--bs-card-color);
  }

.card-header {
    padding: var(--bs-card-cap-padding-y) var(--bs-card-cap-padding-x);
    margin-bottom: 0;
    color: var(--bs-card-cap-color);
    background-color: var(--bs-card-cap-bg);
    border-bottom: var(--bs-card-border-width) solid var(--bs-card-border-color);
  }
.card-header:first-child {
    border-radius: var(--bs-card-inner-border-radius) var(--bs-card-inner-border-radius) 0 0;
  }
  

.btn {
    --bs-btn-padding-x: 0.75rem;
    --bs-btn-padding-y: 0.375rem;
    --bs-btn-font-family: ;
    --bs-btn-font-size: 1rem;
    --bs-btn-font-weight: 400;
    --bs-btn-line-height: 1.5;
    --bs-btn-color: #212529;
    --bs-btn-bg: transparent;
    --bs-btn-border-width: 1px;
    --bs-btn-border-color: transparent;
    --bs-btn-border-radius: 0.375rem;
    --bs-btn-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075);
    --bs-btn-disabled-opacity: 0.65;
    --bs-btn-focus-box-shadow: 0 0 0 0.25rem rgba(var(--bs-btn-focus-shadow-rgb), .5);
    display: inline-block;
    padding: var(--bs-btn-padding-y) var(--bs-btn-padding-x);
    font-family: var(--bs-btn-font-family);
    font-size: var(--bs-btn-font-size);
    font-weight: var(--bs-btn-font-weight);
    line-height: var(--bs-btn-line-height);
    color: var(--bs-btn-color);
    text-align: center;
    text-decoration: none;
    vertical-align: middle;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    user-select: none;
    border: var(--bs-btn-border-width) solid var(--bs-btn-border-color);
    border-radius: var(--bs-btn-border-radius);
    background-color: var(--bs-btn-bg);
    transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
  }
@media (prefers-reduced-motion: reduce) {
    .btn {
      transition: none;
    }
  }
.btn:hover {
    color: var(--bs-btn-hover-color);
    background-color: var(--bs-btn-hover-bg);
    border-color: var(--bs-btn-hover-border-color);
  }
.btn-check:focus + .btn, .btn:focus {
    color: var(--bs-btn-hover-color);
    background-color: var(--bs-btn-hover-bg);
    border-color: var(--bs-btn-hover-border-color);
    outline: 0;
    box-shadow: var(--bs-btn-focus-box-shadow);
  }
.btn-check:checked + .btn, .btn-check:active + .btn, .btn:active, .btn.active, .btn.show {
    color: var(--bs-btn-active-color);
    background-color: var(--bs-btn-active-bg);
    border-color: var(--bs-btn-active-border-color);
  }
.btn-check:checked + .btn:focus, .btn-check:active + .btn:focus, .btn:active:focus, .btn.active:focus, .btn.show:focus {
    box-shadow: var(--bs-btn-focus-box-shadow);
  }
.btn:disabled, .btn.disabled, fieldset:disabled .btn {
    color: var(--bs-btn-disabled-color);
    pointer-events: none;
    background-color: var(--bs-btn-disabled-bg);
    border-color: var(--bs-btn-disabled-border-color);
    opacity: var(--bs-btn-disabled-opacity);
  }


.text-decoration-none{
    text-decoration: none;
    color: black;
}
.fs10{
    font-size: 10px;
}
.z100{
    z-index: 100 !important;
}