# Generated by Django 4.1 on 2022-09-03 11:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('whatsapp_call', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='whatsapp',
            name='draft',
            field=models.TextField(blank=True, null=True),
        ),
    ]
